@@ -1,43 +1,32 @@
 from http import HTTPStatus
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Optional, Union
 
 import httpx
 
 from ... import errors
-from ...client import Client
-from ...models.delete_dbt_cloud_integration_settings_response_200 import (
-    DeleteDbtCloudIntegrationSettingsResponse200,
+from ...client import AuthenticatedClient, Client
+from ...models.api_dbt_cloud_settings_delete_success import (
+    ApiDbtCloudSettingsDeleteSuccess,
 )
 from ...types import Response
 
 
 def _get_kwargs(
     project_uuid: str,
-    *,
-    client: Client,
 ) -> Dict[str, Any]:
-    url = "{}/api/v1/projects/{projectUuid}/integrations/dbt-cloud/settings".format(
-        client.base_url, projectUuid=project_uuid
-    )
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
-
-    return {
+    _kwargs: Dict[str, Any] = {
         "method": "delete",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
-        "follow_redirects": client.follow_redirects,
+        "url": f"/api/v1/projects/{project_uuid}/integrations/dbt-cloud/settings",
     }
 
+    return _kwargs
+
 
 def _parse_response(
-    *, client: Client, response: httpx.Response
-) -> Optional[DeleteDbtCloudIntegrationSettingsResponse200]:
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[ApiDbtCloudSettingsDeleteSuccess]:
     if response.status_code == HTTPStatus.OK:
-        response_200 = DeleteDbtCloudIntegrationSettingsResponse200.from_dict(response.json())
+        response_200 = ApiDbtCloudSettingsDeleteSuccess.from_dict(response.json())
 
         return response_200
     if client.raise_on_unexpected_status:
@@ -47,8 +36,8 @@ def _parse_response(
 
 
 def _build_response(
-    *, client: Client, response: httpx.Response
-) -> Response[DeleteDbtCloudIntegrationSettingsResponse200]:
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[ApiDbtCloudSettingsDeleteSuccess]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -60,8 +49,8 @@ def _build_response(
 def sync_detailed(
     project_uuid: str,
     *,
-    client: Client,
-) -> Response[DeleteDbtCloudIntegrationSettingsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Response[ApiDbtCloudSettingsDeleteSuccess]:
     """Remove the dbt Cloud integration settings for a project
 
     Args:
@@ -72,16 +61,14 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[DeleteDbtCloudIntegrationSettingsResponse200]
+        Response[ApiDbtCloudSettingsDeleteSuccess]
     """
 
     kwargs = _get_kwargs(
         project_uuid=project_uuid,
-        client=client,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
@@ -91,8 +78,8 @@ def sync_detailed(
 def sync(
     project_uuid: str,
     *,
-    client: Client,
-) -> Optional[DeleteDbtCloudIntegrationSettingsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Optional[ApiDbtCloudSettingsDeleteSuccess]:
     """Remove the dbt Cloud integration settings for a project
 
     Args:
@@ -103,7 +90,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        DeleteDbtCloudIntegrationSettingsResponse200
+        ApiDbtCloudSettingsDeleteSuccess
     """
 
     return sync_detailed(
@@ -115,8 +102,8 @@ def sync(
 async def asyncio_detailed(
     project_uuid: str,
     *,
-    client: Client,
-) -> Response[DeleteDbtCloudIntegrationSettingsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Response[ApiDbtCloudSettingsDeleteSuccess]:
     """Remove the dbt Cloud integration settings for a project
 
     Args:
@@ -127,16 +114,14 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[DeleteDbtCloudIntegrationSettingsResponse200]
+        Response[ApiDbtCloudSettingsDeleteSuccess]
     """
 
     kwargs = _get_kwargs(
         project_uuid=project_uuid,
-        client=client,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
     return _build_response(client=client, response=response)
 
@@ -144,8 +129,8 @@ async def asyncio_detailed(
 async def asyncio(
     project_uuid: str,
     *,
-    client: Client,
-) -> Optional[DeleteDbtCloudIntegrationSettingsResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Optional[ApiDbtCloudSettingsDeleteSuccess]:
     """Remove the dbt Cloud integration settings for a project
 
     Args:
@@ -156,7 +141,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        DeleteDbtCloudIntegrationSettingsResponse200
+        ApiDbtCloudSettingsDeleteSuccess
     """
 
     return (
