@@ -1,43 +1,42 @@
 from http import HTTPStatus
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Optional, Union
 
 import httpx
 
 from ... import errors
-from ...client import Client
-from ...models.update_my_organization_json_body import UpdateMyOrganizationJsonBody
-from ...models.update_my_organization_response_200 import (
-    UpdateMyOrganizationResponse200,
+from ...client import AuthenticatedClient, Client
+from ...models.api_success_empty import ApiSuccessEmpty
+from ...models.partial_omit_organization_organization_uuid_or_needs_project import (
+    PartialOmitOrganizationOrganizationUuidOrNeedsProject,
 )
 from ...types import Response
 
 
 def _get_kwargs(
     *,
-    client: Client,
-    json_body: UpdateMyOrganizationJsonBody,
+    body: PartialOmitOrganizationOrganizationUuidOrNeedsProject,
 ) -> Dict[str, Any]:
-    url = "{}/api/v1/org".format(client.base_url)
+    headers: Dict[str, Any] = {}
 
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
-
-    json_json_body = json_body.to_dict()
-
-    return {
+    _kwargs: Dict[str, Any] = {
         "method": "patch",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
-        "follow_redirects": client.follow_redirects,
-        "json": json_json_body,
+        "url": "/api/v1/org",
     }
 
+    _body = body.to_dict()
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[UpdateMyOrganizationResponse200]:
+    _kwargs["json"] = _body
+    headers["Content-Type"] = "application/json"
+
+    _kwargs["headers"] = headers
+    return _kwargs
+
+
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[ApiSuccessEmpty]:
     if response.status_code == HTTPStatus.OK:
-        response_200 = UpdateMyOrganizationResponse200.from_dict(response.json())
+        response_200 = ApiSuccessEmpty.from_dict(response.json())
 
         return response_200
     if client.raise_on_unexpected_status:
@@ -46,7 +45,9 @@ def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Upd
         return None
 
 
-def _build_response(*, client: Client, response: httpx.Response) -> Response[UpdateMyOrganizationResponse200]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[ApiSuccessEmpty]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -57,29 +58,28 @@ def _build_response(*, client: Client, response: httpx.Response) -> Response[Upd
 
 def sync_detailed(
     *,
-    client: Client,
-    json_body: UpdateMyOrganizationJsonBody,
-) -> Response[UpdateMyOrganizationResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: PartialOmitOrganizationOrganizationUuidOrNeedsProject,
+) -> Response[ApiSuccessEmpty]:
     """Update the current user's organization
 
     Args:
-        json_body (UpdateMyOrganizationJsonBody): the new organization settings
+        body (PartialOmitOrganizationOrganizationUuidOrNeedsProject): Make all properties in T
+            optional
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[UpdateMyOrganizationResponse200]
+        Response[ApiSuccessEmpty]
     """
 
     kwargs = _get_kwargs(
-        client=client,
-        json_body=json_body,
+        body=body,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
@@ -88,78 +88,79 @@ def sync_detailed(
 
 def sync(
     *,
-    client: Client,
-    json_body: UpdateMyOrganizationJsonBody,
-) -> Optional[UpdateMyOrganizationResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: PartialOmitOrganizationOrganizationUuidOrNeedsProject,
+) -> Optional[ApiSuccessEmpty]:
     """Update the current user's organization
 
     Args:
-        json_body (UpdateMyOrganizationJsonBody): the new organization settings
+        body (PartialOmitOrganizationOrganizationUuidOrNeedsProject): Make all properties in T
+            optional
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        UpdateMyOrganizationResponse200
+        ApiSuccessEmpty
     """
 
     return sync_detailed(
         client=client,
-        json_body=json_body,
+        body=body,
     ).parsed
 
 
 async def asyncio_detailed(
     *,
-    client: Client,
-    json_body: UpdateMyOrganizationJsonBody,
-) -> Response[UpdateMyOrganizationResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: PartialOmitOrganizationOrganizationUuidOrNeedsProject,
+) -> Response[ApiSuccessEmpty]:
     """Update the current user's organization
 
     Args:
-        json_body (UpdateMyOrganizationJsonBody): the new organization settings
+        body (PartialOmitOrganizationOrganizationUuidOrNeedsProject): Make all properties in T
+            optional
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[UpdateMyOrganizationResponse200]
+        Response[ApiSuccessEmpty]
     """
 
     kwargs = _get_kwargs(
-        client=client,
-        json_body=json_body,
+        body=body,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
     return _build_response(client=client, response=response)
 
 
 async def asyncio(
     *,
-    client: Client,
-    json_body: UpdateMyOrganizationJsonBody,
-) -> Optional[UpdateMyOrganizationResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: PartialOmitOrganizationOrganizationUuidOrNeedsProject,
+) -> Optional[ApiSuccessEmpty]:
     """Update the current user's organization
 
     Args:
-        json_body (UpdateMyOrganizationJsonBody): the new organization settings
+        body (PartialOmitOrganizationOrganizationUuidOrNeedsProject): Make all properties in T
+            optional
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        UpdateMyOrganizationResponse200
+        ApiSuccessEmpty
     """
 
     return (
         await asyncio_detailed(
             client=client,
-            json_body=json_body,
+            body=body,
         )
     ).parsed
