@@ -1,44 +1,41 @@
 from http import HTTPStatus
-from typing import Any
-from typing import Dict
-from typing import Optional
+from typing import Any, Dict, Optional, Union
 
 import httpx
 
 from ... import errors
-from ...client import Client
-from ...models.grant_project_access_to_user_json_body import GrantProjectAccessToUserJsonBody
-from ...models.grant_project_access_to_user_response_200 import GrantProjectAccessToUserResponse200
+from ...client import AuthenticatedClient, Client
+from ...models.api_success_empty import ApiSuccessEmpty
+from ...models.create_project_member import CreateProjectMember
 from ...types import Response
 
 
 def _get_kwargs(
     project_uuid: str,
     *,
-    client: Client,
-    json_body: GrantProjectAccessToUserJsonBody,
+    body: CreateProjectMember,
 ) -> Dict[str, Any]:
-    url = "{}/api/v1/projects/{projectUuid}/access".format(client.base_url, projectUuid=project_uuid)
+    headers: Dict[str, Any] = {}
 
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
-
-    json_json_body = json_body.to_dict()
-
-    return {
+    _kwargs: Dict[str, Any] = {
         "method": "post",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
-        "follow_redirects": client.follow_redirects,
-        "json": json_json_body,
+        "url": f"/api/v1/projects/{project_uuid}/access",
     }
 
+    _body = body.to_dict()
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[GrantProjectAccessToUserResponse200]:
+    _kwargs["json"] = _body
+    headers["Content-Type"] = "application/json"
+
+    _kwargs["headers"] = headers
+    return _kwargs
+
+
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[ApiSuccessEmpty]:
     if response.status_code == HTTPStatus.OK:
-        response_200 = GrantProjectAccessToUserResponse200.from_dict(response.json())
+        response_200 = ApiSuccessEmpty.from_dict(response.json())
 
         return response_200
     if client.raise_on_unexpected_status:
@@ -47,7 +44,9 @@ def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Gra
         return None
 
 
-def _build_response(*, client: Client, response: httpx.Response) -> Response[GrantProjectAccessToUserResponse200]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[ApiSuccessEmpty]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -59,31 +58,29 @@ def _build_response(*, client: Client, response: httpx.Response) -> Response[Gra
 def sync_detailed(
     project_uuid: str,
     *,
-    client: Client,
-    json_body: GrantProjectAccessToUserJsonBody,
-) -> Response[GrantProjectAccessToUserResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: CreateProjectMember,
+) -> Response[ApiSuccessEmpty]:
     """Grant a user access to a project
 
     Args:
         project_uuid (str):
-        json_body (GrantProjectAccessToUserJsonBody):
+        body (CreateProjectMember):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[GrantProjectAccessToUserResponse200]
+        Response[ApiSuccessEmpty]
     """
 
     kwargs = _get_kwargs(
         project_uuid=project_uuid,
-        client=client,
-        json_body=json_body,
+        body=body,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
@@ -93,58 +90,56 @@ def sync_detailed(
 def sync(
     project_uuid: str,
     *,
-    client: Client,
-    json_body: GrantProjectAccessToUserJsonBody,
-) -> Optional[GrantProjectAccessToUserResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: CreateProjectMember,
+) -> Optional[ApiSuccessEmpty]:
     """Grant a user access to a project
 
     Args:
         project_uuid (str):
-        json_body (GrantProjectAccessToUserJsonBody):
+        body (CreateProjectMember):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        GrantProjectAccessToUserResponse200
+        ApiSuccessEmpty
     """
 
     return sync_detailed(
         project_uuid=project_uuid,
         client=client,
-        json_body=json_body,
+        body=body,
     ).parsed
 
 
 async def asyncio_detailed(
     project_uuid: str,
     *,
-    client: Client,
-    json_body: GrantProjectAccessToUserJsonBody,
-) -> Response[GrantProjectAccessToUserResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: CreateProjectMember,
+) -> Response[ApiSuccessEmpty]:
     """Grant a user access to a project
 
     Args:
         project_uuid (str):
-        json_body (GrantProjectAccessToUserJsonBody):
+        body (CreateProjectMember):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[GrantProjectAccessToUserResponse200]
+        Response[ApiSuccessEmpty]
     """
 
     kwargs = _get_kwargs(
         project_uuid=project_uuid,
-        client=client,
-        json_body=json_body,
+        body=body,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
     return _build_response(client=client, response=response)
 
@@ -152,27 +147,27 @@ async def asyncio_detailed(
 async def asyncio(
     project_uuid: str,
     *,
-    client: Client,
-    json_body: GrantProjectAccessToUserJsonBody,
-) -> Optional[GrantProjectAccessToUserResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: CreateProjectMember,
+) -> Optional[ApiSuccessEmpty]:
     """Grant a user access to a project
 
     Args:
         project_uuid (str):
-        json_body (GrantProjectAccessToUserJsonBody):
+        body (CreateProjectMember):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        GrantProjectAccessToUserResponse200
+        ApiSuccessEmpty
     """
 
     return (
         await asyncio_detailed(
             project_uuid=project_uuid,
             client=client,
-            json_body=json_body,
+            body=body,
         )
     ).parsed
